"
I manage the installation of Grafoscopio. Grafoscopio is a tool for interative notebooks/documentation and data visualization.

For more details about this project, look for the
Grafoscopio package in the system browser or at: http://mutabit.com/grafoscopio/index.en.html
"
Class {
	#name : #ConfigurationOfGrafoscopio,
	#superclass : #Object,
	#instVars : [
		'project'
	],
	#classVars : [
		'LastVersionLoad'
	],
	#category : 'ConfigurationOfGrafoscopio'
}

{ #category : #'development support' }
ConfigurationOfGrafoscopio class >> DevelopmentSupport [

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>

]

{ #category : #private }
ConfigurationOfGrafoscopio class >> baseConfigurationClassIfAbsent: aBlock [

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].

]

{ #category : #catalog }
ConfigurationOfGrafoscopio class >> catalogContactInfo [
	^'mail: info@mutabit.com | web: http://mutabit.com/grafoscopio/'
]

{ #category : #catalog }
ConfigurationOfGrafoscopio class >> catalogDescription [
	^'Grafoscopio is a tool to create interactive notebooks and documentation for computer narratives and data visualization.
	They are structured as outlines/trees containing textual and code nodes that can be exported to several formats: LaTeX, HTML
	and pdf (via pandoc).
	It can be used in several endeavors like: reproductible open research and science, data journalism, data activism among others'
]

{ #category : #catalog }
ConfigurationOfGrafoscopio class >> catalogKeywords [
	^ #(#'data-activism' #'data-journalism' #'data-science' #'data-visualization' documentation #'interactive-notebook' 'markup' 'markdown' #'open-data' #'open-research' #'open-science' #'reproducible-research')
]

{ #category : #private }
ConfigurationOfGrafoscopio class >> ensureMetacello [

	(self baseConfigurationClassIfAbsent: []) ensureMetacello
]

{ #category : #private }
ConfigurationOfGrafoscopio class >> ensureMetacelloBaseConfiguration [

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]
]

{ #category : #'metacello tool support' }
ConfigurationOfGrafoscopio class >> isMetacelloConfig [
	"Answer true and the Metacello tools will operate on you"
	
	^true
]

{ #category : #loading }
ConfigurationOfGrafoscopio class >> load [
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load
]

{ #category : #loading }
ConfigurationOfGrafoscopio class >> loadBleedingEdge [
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load
]

{ #category : #loading }
ConfigurationOfGrafoscopio class >> loadDevelopment [
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load
]

{ #category : #accessing }
ConfigurationOfGrafoscopio class >> project [

	^self new project
]

{ #category : #'development support' }
ConfigurationOfGrafoscopio class >> validate [
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore
]

{ #category : #baselines }
ConfigurationOfGrafoscopio >> baseline010: spec [
	<version: '0.10-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://smalltalkhub.com/Offray/Grafoscopio'.
		spec 
			project: 'Dataviz' with: [
				spec
					className: #ConfigurationOfDataviz;
					versionString: '2.2.2';
					repository: 'http://smalltalkhub.com/mc/Offray/Dataviz/main/' ];
			project: 'Roassal2' with: [
				spec
					className: #ConfigurationOfRoassal2;
					versionString: #'stable';
					repository: 'http://smalltalkhub.com/mc/ObjectProfile/Roassal2/main/' ];
			project: 'Ston' with: [
				spec
					className: #ConfigurationOfSton;
					versionString: '0.19';
					repository: 'http://ss3.gemstone.com/ss/STON' ];
			project: 'WebBrowser' with: [
				spec
					className: #ConfigurationOfWebBrowser;
					versionString: #'stable';
					repository: 'http://smalltalkhub.com/mc/Pharo/MetaRepoForPharo60/main/' ].
		spec 
			package: #Grafoscopio with: [
				spec requires: #('Spec-Glamour' ). ];
			package: 'Spec-Glamour'.
		spec 
			group: 'Core' with: #('Grafoscopio' 'Roassal2' );
			group: 'Extended' with: #('Core' 'Dataviz' ). ].

]

{ #category : #baselines }
ConfigurationOfGrafoscopio >> baseline01: spec [
	<version: '0.1-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://smalltalkhub.com/mc/Offray/Grafoscopio/main/'.
		spec project: 'Ston' with: [
				spec
					className: #ConfigurationOfSton;
					versionString: #'stable';
					repository: 'http://ss3.gemstone.com/ss/STON' ].
		spec package: #Grafoscopio.
		spec group: 'Core' with: #(#Grafoscopio ). ].

]

{ #category : #baselines }
ConfigurationOfGrafoscopio >> baseline02: spec [
	<version: '0.2-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://smalltalkhub.com/mc/Offray/Grafoscopio/main/'.
		spec project: 'Ston' with: [
				spec
					className: #ConfigurationOfSton;
					versionString: #'stable';
					repository: 'http://smalltalkhub.com/mc/Pharo/MetaRepoForPharo40/main/';
					repository: 'http://ss3.gemstone.com/ss/STON' ].
		spec package: #Grafoscopio.
		spec group: 'Core' with: #(#Grafoscopio ). ].

]

{ #category : #baselines }
ConfigurationOfGrafoscopio >> baseline03: spec [
	<version: '0.3-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://smalltalkhub.com/mc/Pharo/MetaRepoForPharo50/main/'.
		spec project: 'Ston' with: [
				spec
					className: #ConfigurationOfSton;
					versionString: #'stable';
					repository: 'http://smalltalkhub.com/mc/Pharo/MetaRepoForPharo40/main/';
					repository: 'http://ss3.gemstone.com/ss/STON' ].
		spec package: #Grafoscopio.
		spec group: 'Core' with: #(#Grafoscopio ). ].

]

{ #category : #baselines }
ConfigurationOfGrafoscopio >> baseline04: spec [
	<version: '0.4-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://smalltalkhub.com/mc/Pharo/MetaRepoForPharo40/main/'.
		spec project: 'Ston' with: [
				spec
					className: #ConfigurationOfSton;
					versionString: '0.14';
					repository: 'http://smalltalkhub.com/mc/Pharo/MetaRepoForPharo40/main/';
					repository: 'http://ss3.gemstone.com/ss/STON' ].
		spec package: #Grafoscopio.
		spec group: 'Core' with: #(). ].

]

{ #category : #baselines }
ConfigurationOfGrafoscopio >> baseline05: spec [
	<version: '0.5-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://smalltalkhub.com/Offray/Grafoscopio'.
		spec project: 'Ston' with: [
				spec
					className: #ConfigurationOfSton;
					versionString: '0.14';
					repository: 'http://ss3.gemstone.com/ss/STON' ].
		spec package: #Grafoscopio.
		spec group: 'Core' with: #(). ].

]

{ #category : #baselines }
ConfigurationOfGrafoscopio >> baseline06: spec [
	<version: '0.6-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://smalltalkhub.com/Offray/Grafoscopio'.
		spec project: 'Ston' with: [
				spec
					className: #ConfigurationOfSton;
					versionString: #'stable';
					repository: 'http://ss3.gemstone.com/ss/STON' ].
		spec package: #Grafoscopio.
		spec group: 'Core' with: #(). ].

]

{ #category : #baselines }
ConfigurationOfGrafoscopio >> baseline07: spec [
	<version: '0.7-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://smalltalkhub.com/Offray/Grafoscopio'.
		spec 
			project: 'Ston' with: [
				spec
					className: #ConfigurationOfSton;
					versionString: #'stable';
					repository: 'http://ss3.gemstone.com/ss/STON' ];
			project: 'Roassal2' with: [
				spec
					className: #ConfigurationOfRoassal2;
					versionString: #'stable';
					repository: 'http://smalltalkhub.com/mc/ObjectProfile/Roassal2/main/' ].
		spec package: #Grafoscopio.
		spec group: 'Core' with: #(). ].

]

{ #category : #baselines }
ConfigurationOfGrafoscopio >> baseline08: spec [
	<version: '0.8-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://smalltalkhub.com/Offray/Grafoscopio'.
		spec 
			project: 'Dataviz' with: [
				spec
					className: #ConfigurationOfDataviz;
					versionString: '2.1';
					repository: 'http://smalltalkhub.com/mc/Offray/Dataviz/main/' ];
			project: 'Roassal2' with: [
				spec
					className: #ConfigurationOfRoassal2;
					versionString: '1.38';
					repository: 'http://smalltalkhub.com/mc/ObjectProfile/Roassal2/main/' ];
			project: 'Ston' with: [
				spec
					className: #ConfigurationOfSton;
					versionString: #'bleedingEdge';
					repository: 'http://ss3.gemstone.com/ss/STON' ].
		spec 
			package: #Grafoscopio with: [
				spec requires: #('Spec-Glamour' ). ];
			package: 'Spec-Glamour'.
		spec 
			group: 'Core' with: #('Grafoscopio' 'Roassal2' );
			group: 'Extended' with: #('Core' 'Dataviz' ). ].

]

{ #category : #baselines }
ConfigurationOfGrafoscopio >> baseline09: spec [
	<version: '0.9-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://smalltalkhub.com/Offray/Grafoscopio'.
		spec 
			project: 'Dataviz' with: [
				spec
					className: #ConfigurationOfDataviz;
					versionString: '2.2.2';
					repository: 'http://smalltalkhub.com/mc/Offray/Dataviz/main/' ];
			project: 'Roassal2' with: [
				spec
					className: #ConfigurationOfRoassal2;
					versionString: #'stable';
					repository: 'http://smalltalkhub.com/mc/ObjectProfile/Roassal2/main/' ];
			project: 'Ston' with: [
				spec
					className: #ConfigurationOfSton;
					versionString: '0.19';
					repository: 'http://ss3.gemstone.com/ss/STON' ];
			project: 'WebBrowser' with: [
				spec
					className: #ConfigurationOfWebBrowser;
					versionString: #'stable';
					repository: 'http://smalltalkhub.com/mc/Pharo/MetaRepoForPharo60/main/' ].
		spec 
			package: #Grafoscopio with: [
				spec requires: #('Spec-Glamour' ). ];
			package: 'Spec-Glamour'.
		spec 
			group: 'Core' with: #('Grafoscopio' 'Roassal2' );
			group: 'Extended' with: #('Core' 'Dataviz' ). ].

]

{ #category : #baselines }
ConfigurationOfGrafoscopio >> baseline131: spec [
	<version: '1.3.1-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec 
			repository: 'http://smalltalkhub.com/Offray/Grafoscopio';
			package: #'Grafoscopio-Utils'.
		spec 
			project: 'Ston' with: [
				spec
					className: #ConfigurationOfSton;
					versionString: #'bleedingEdge';
					repository: 'http://ss3.gemstone.com/ss/STON' ];
			project: 'NeoJSON' with: [
				spec
					className: #ConfigurationOfJSON;
					versionString: #'stable';
					repository: 'http://mc.stfx.eu/Neo' ];	
			project: 'Roassal2' with: [
				spec
					className: #ConfigurationOfRoassal2;
					versionString: #'stable';
					repository: 'http://smalltalkhub.com/mc/ObjectProfile/Roassal2/main/' ];
			project: 'WebBrowser' with: [ 
				spec 
					className: #ConfigurationOfWebBrowser;
					versionString: #stable;
					repository: 'http://smalltalkhub.com/TorstenBergmann/WebBrowser'];
			"I need to replace this with the configuration of OSSubProcess:
			 
			project: 'OSProcess' with: [ 
				spec 
					className: #ConfigurationOfOSProcess;
					versionString: #stable;
					repository: 'http://www.squeaksource.com/OSProcess'];	 	"
			package: 'Spec-Glamour' with:[ 
				spec repository: 'http://smalltalkhub.com/mc/jfabry/Playground/main/' ];
			project: 'Fossil' with: [
				spec
					className: #ConfigurationOfFossil;
					versionString: #'stable';
					repository: 'http://smalltalkhub.com/mc/Offray/Fossil/main' ].
		spec package: #Grafoscopio with: [
				spec 
					requires: #('Ston' 'Spec-Glamour' 'Fossil')].
		spec 
			group: 'Core' with: #('Grafoscopio-Utils' 'Roassal2' 'Grafoscopio');
			group: 'Extended' with: #('Core') ].
]

{ #category : #baselines }
ConfigurationOfGrafoscopio >> baseline132: spec [
	<version: '1.3.2-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec 
			repository: 'http://smalltalkhub.com/Offray/Grafoscopio';
			package: #'Grafoscopio-Utils'.
		spec 
			project: 'Ston' with: [
				spec
					className: #ConfigurationOfSton;
					versionString: #'bleedingEdge';
					repository: 'http://ss3.gemstone.com/ss/STON' ];	
			project: 'Roassal2' with: [
				spec
					className: #ConfigurationOfRoassal2;
					versionString: #'stable';
					repository: 'http://smalltalkhub.com/mc/ObjectProfile/Roassal2/main/' ];
			project: 'WebBrowser' with: [ 
				spec 
					className: #ConfigurationOfWebBrowser;
					versionString: #stable;
					repository: 'http://smalltalkhub.com/TorstenBergmann/WebBrowser'];
			"I need to replace this with the configuration of OSSubProcess:
			 
			project: 'OSProcess' with: [ 
				spec 
					className: #ConfigurationOfOSProcess;
					versionString: #stable;
					repository: 'http://www.squeaksource.com/OSProcess'];	 	"
			package: 'Spec-Glamour' with:[ 
				spec repository: 'http://smalltalkhub.com/mc/jfabry/Playground/main/' ];
			project: 'Fossil' with: [
				spec
					className: #ConfigurationOfFossil;
					versionString: #'stable';
					repository: 'http://smalltalkhub.com/mc/Offray/Fossil/main' ].
		spec package: #Grafoscopio with: [
				spec 
					requires: #('Ston' 'Spec-Glamour' 'Fossil')].
		spec 
			group: 'Core' with: #('Grafoscopio-Utils' 'Roassal2' 'Grafoscopio');
			group: 'Extended' with: #('Core') ].
]

{ #category : #baselines }
ConfigurationOfGrafoscopio >> baseline133: spec [
	<version: '1.3.3-baseline'>
	spec
		for: #common
		do: [ spec blessing: #baseline.
			spec
				repository: 'http://smalltalkhub.com/Offray/Grafoscopio';
				package: #'Grafoscopio-Utils'.
			spec
				project: 'Ston'
					with: [ spec
						className: #ConfigurationOfSton;
						versionString: #bleedingEdge;
						repository: 'http://ss3.gemstone.com/ss/STON' ];
				project: 'Roassal2'
					with: [ spec
						className: #ConfigurationOfRoassal2;
						versionString: #stable;
						repository: 'http://smalltalkhub.com/mc/ObjectProfile/Roassal2/main/' ];
				project: 'WebBrowser'
					with: [ spec
						className: #ConfigurationOfWebBrowser;
						versionString: #stable;
						repository: 'http://smalltalkhub.com/TorstenBergmann/WebBrowser' ];
				baseline: #TaskitShell
					with: [ spec repository: 'github://sbragagnolo/taskit:master/' ];
				package: 'Spec-Glamour'
					with: [ spec
						repository: 'http://smalltalkhub.com/mc/jfabry/Playground/main/' ];
				project: 'Fossil'
					with: [ spec
						className: #ConfigurationOfFossil;
						versionString: #stable;
						repository: 'http://smalltalkhub.com/mc/Offray/Fossil/main' ].
			spec
				package: #Grafoscopio
				with: [ spec requires: #('Ston' 'Spec-Glamour' 'Fossil' 'TaskitShell') ].
			spec
				group: 'Core'
					with: #('Grafoscopio-Utils' 'Roassal2' 'Grafoscopio');
				group: 'Extended' with: #('Core') ]
]

{ #category : #baselines }
ConfigurationOfGrafoscopio >> baseline1_0: spec [
	<version: '1.0-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://smalltalkhub.com/Offray/Grafoscopio'.
		spec 
			project: 'Ston' with: [
				spec
					className: #ConfigurationOfSton;
					versionString: #'bleedingEdge';
					repository: 'http://ss3.gemstone.com/ss/STON' ];
			project: 'Roassal2' with: [
				spec
					className: #ConfigurationOfRoassal2;
					versionString: #'bleedingEdge';
					repository: 'http://smalltalkhub.com/mc/ObjectProfile/Roassal2/main/' ];
			package: 'Spec-Glamour' with:[ 
				spec repository: 'http://smalltalkhub.com/mc/jfabry/Playground/main/' ];
			project: 'Dataviz' with: [
				spec
					className: #ConfigurationOfDataviz;
					versionString: #'bleedingEdge';
					repository: 'http://smalltalkhub.com/mc/Offray/Dataviz/main/' ].
		spec package: #Grafoscopio with: [
				spec 
					requires: 'Ston';
					requires: 'Spec-Glamour'].
		spec 
			group: 'Core' with: #('Grafoscopio' 'Roassal2');
			group: 'Extended' with: #('Core' 'Dataviz') ].

]

{ #category : #baselines }
ConfigurationOfGrafoscopio >> baseline1_1: spec [
	<version: '1.1-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://smalltalkhub.com/Offray/Grafoscopio'.
		spec 
			project: 'Ston' with: [
				spec
					className: #ConfigurationOfSton;
					versionString: #'bleedingEdge';
					repository: 'http://ss3.gemstone.com/ss/STON' ];
			project: 'Roassal2' with: [
				spec
					className: #ConfigurationOfRoassal2;
					versionString: #'bleedingEdge';
					repository: 'http://smalltalkhub.com/mc/ObjectProfile/Roassal2/main/' ];
			project: 'WebBrowser' with: [ 
				spec 
					className: #ConfigurationOfWebBrowser;
					versionString: #stable;
					repository: 'http://smalltalkhub.com/TorstenBergmann/WebBrowser'];
			project: 'OSProcess' with: [ 
				spec 
					className: #ConfigurationOfOSProcess;
					versionString: #stable;
					repository: 'http://www.squeaksource.com/OSProcess'];	 	
			package: 'Spec-Glamour' with:[ 
				spec repository: 'http://smalltalkhub.com/mc/jfabry/Playground/main/' ];
			project: 'Zotero' with: [
				spec
					className: #ConfigurationOfPubiblio;
					versionString: #'stable';
					repository: 'http://smalltalkhub.com/mc/Offray/Grafoscopio/main' ];
			project: 'Dataviz' with: [
				spec
					className: #ConfigurationOfDataviz;
					versionString: #'bleedingEdge';
					repository: 'http://smalltalkhub.com/mc/Offray/Dataviz/main/' ].
		spec package: #Grafoscopio with: [
				spec 
					requires: 'Ston';
					requires: 'Spec-Glamour';
					requires: 'Grafoscopio-Utils'].
		spec 
			group: 'Core' with: #('Grafoscopio' 'Roassal2');
			group: 'Extended' with: #('Core' 'Dataviz') ].

]

{ #category : #baselines }
ConfigurationOfGrafoscopio >> baseline1_2: spec [
	<version: '1.2-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://smalltalkhub.com/Offray/Grafoscopio'.
		spec 
			project: 'Ston' with: [
				spec
					className: #ConfigurationOfSton;
					versionString: #'bleedingEdge';
					repository: 'http://ss3.gemstone.com/ss/STON' ];
			project: 'Roassal2' with: [
				spec
					className: #ConfigurationOfRoassal2;
					versionString: #'bleedingEdge';
					repository: 'http://smalltalkhub.com/mc/ObjectProfile/Roassal2/main/' ];
			project: 'WebBrowser' with: [ 
				spec 
					className: #ConfigurationOfWebBrowser;
					versionString: #stable;
					repository: 'http://smalltalkhub.com/TorstenBergmann/WebBrowser'];
			"project: 'OSProcess' with: [ 
				spec 
					className: #ConfigurationOfOSProcess;
					versionString: #stable;
					repository: 'http://www.squeaksource.com/OSProcess'];	 	"
			package: 'Spec-Glamour' with:[ 
				spec repository: 'http://smalltalkhub.com/mc/jfabry/Playground/main/' ];
			project: 'Fossil' with: [
				spec
					className: #ConfigurationOfFossil;
					versionString: #'stable';
					repository: 'http://smalltalkhub.com/mc/Offray/Fossil/main' ];
			package: 'Pubiblio' with: [
				spec
					repository: 'http://smalltalkhub.com/mc/Offray/Grafoscopio/main' ];
			project: 'Dataviz' with: [
				spec
					className: #ConfigurationOfDataviz;
					versionString: #'bleedingEdge';
					repository: 'http://smalltalkhub.com/mc/Offray/Dataviz/main/' ].
		spec package: #Grafoscopio with: [
				spec 
					requires: 'Ston';
					requires: 'Spec-Glamour'].
		spec 
			group: 'Core' with: #('Grafoscopio' 'Roassal2');
			group: 'Extended' with: #('Core' 'Dataviz') ].
]

{ #category : #baselines }
ConfigurationOfGrafoscopio >> baseline1_3: spec [
	<version: '1.3-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec 
			repository: 'http://smalltalkhub.com/Offray/Grafoscopio';
			package: #'Grafoscopio-Utils'.
		spec 
			project: 'Ston' with: [
				spec
					className: #ConfigurationOfSton;
					versionString: #'bleedingEdge';
					repository: 'http://ss3.gemstone.com/ss/STON' ];
			project: 'Roassal2' with: [
				spec
					className: #ConfigurationOfRoassal2;
					versionString: #'stable';
					repository: 'http://smalltalkhub.com/mc/ObjectProfile/Roassal2/main/' ];
			project: 'WebBrowser' with: [ 
				spec 
					className: #ConfigurationOfWebBrowser;
					versionString: #stable;
					repository: 'http://smalltalkhub.com/TorstenBergmann/WebBrowser'];
			"I need to replace this with the configuration of OSSubProcess:
			 
			project: 'OSProcess' with: [ 
				spec 
					className: #ConfigurationOfOSProcess;
					versionString: #stable;
					repository: 'http://www.squeaksource.com/OSProcess'];	 	"
			package: 'Spec-Glamour' with:[ 
				spec repository: 'http://smalltalkhub.com/mc/jfabry/Playground/main/' ];
			project: 'Fossil' with: [
				spec
					className: #ConfigurationOfFossil;
					versionString: #'stable';
					repository: 'http://smalltalkhub.com/mc/Offray/Fossil/main' ].
		spec package: #Grafoscopio with: [
				spec 
					requires: 'Ston';
					requires: 'Spec-Glamour'].
		spec 
			group: 'Core' with: #('Grafoscopio-Utils' 'Roassal2' 'Grafoscopio');
			group: 'Extended' with: #('Core') ].
]

{ #category : #baselines }
ConfigurationOfGrafoscopio >> baseline200: spec [
	"protocol: #baselines"

	<version: '2.0.0-baseline'>
	spec
		for: #common
		do: [ spec blessing: #baseline.
			spec
				repository: 'http://smalltalkhub.com/Offray/Grafoscopio';
				package: #'Grafoscopio-Utils'.
			spec
				baseline: #Roassal3
					with: [ spec repository: 'github://ObjectProfile/Roassal3/src' ];
				project: 'WebBrowser'
					with: [ spec
						className: #ConfigurationOfWebBrowser;
						versionString: #stable;
						repository: 'http://smalltalkhub.com/TorstenBergmann/WebBrowser' ];
				baseline: #TaskItShell
					with: [ spec repository: 'github://sbragagnolo/taskit:master/' ];
				baseline: #Pillar
					with: [ spec repository: 'github://pillar-markup/pillar/' ];
				project: 'Fossil'
					with: [ spec
						className: #ConfigurationOfFossil;
						versionString: #stable;
						repository: 'http://smalltalkhub.com/mc/Offray/Fossil/main' ].
			spec
				package: #Grafoscopio
				with: [ spec requires: #('TaskItShell' 'Fossil' 'Pillar') ].
			spec
				group: 'Core'
					with: #('Grafoscopio-Utils' 'Roassal3' 'Grafoscopio');
				group: 'Extended' with: #('Core') ]
]

{ #category : #accessing }
ConfigurationOfGrafoscopio >> customProjectAttributes [
	 "Edit to return a collection of any custom attributes e.g. for conditional loading: Array with: #'Condition1' with: #'Condition2.
	For more information see: http://code.google.com/p/metacello/wiki/CustomProjectAttrributes"

	^ #().
]

{ #category : #'symbolic versions' }
ConfigurationOfGrafoscopio >> development: spec [
	<symbolicVersion: #'development'>

	spec for: #'common' version: '1.5'.

]

{ #category : #'as yet unclassified' }
ConfigurationOfGrafoscopio >> postLoadForGrafoscopio [
	GrafoscopioBrowser startDockingBar
]

{ #category : #accessing }
ConfigurationOfGrafoscopio >> project [

	^ project ifNil: [ 
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		project := MetacelloMCProject new projectAttributes: self customProjectAttributes. 
		(Smalltalk at: #MetacelloVersionConstructor) on: self project: project.
		project loadType: #linear. "change to #atomic if desired"
		project ]
]

{ #category : #'symbolic versions' }
ConfigurationOfGrafoscopio >> stable: spec [
	<symbolicVersion: #'stable'>

	spec for: #'common' version: '1.5.5'.

]

{ #category : #versions }
ConfigurationOfGrafoscopio >> version01: spec [
	<version: '0.1' imports: #('0.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.1'.
		spec author: 'OffrayLuna'.
		spec timestamp: '2/22/2016 17:43'.
		spec project: 'Ston' with: '0.14'.
		spec package: #Grafoscopio with: 'Grafoscopio-OffrayLuna.146'. ].

]

{ #category : #versions }
ConfigurationOfGrafoscopio >> version02: spec [
	<version: '0.2' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.2'.
		spec author: 'OffrayLuna'.
		spec timestamp: '2/22/2016 21:58'.
		spec project: 'Ston' with: '0.14'.
		spec package: #Grafoscopio with: 'Grafoscopio-OffrayLuna.146'. ].

]

{ #category : #versions }
ConfigurationOfGrafoscopio >> version03: spec [
	<version: '0.3' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.3'.
		spec author: 'OffrayLuna'.
		spec timestamp: '2/22/2016 22:43'.
		spec project: 'Ston' with: '0.14'.
		spec package: #Grafoscopio with: 'Grafoscopio-OffrayLuna.146'. ].

]

{ #category : #versions }
ConfigurationOfGrafoscopio >> version04: spec [
	<version: '0.4' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.4'.
		spec author: 'OffrayLuna'.
		spec timestamp: '2/23/2016 15:29'.
		spec project: 'Ston' with: '0.14'.
		spec package: #Grafoscopio with: 'Grafoscopio-OffrayLuna.146'. ].

]

{ #category : #versions }
ConfigurationOfGrafoscopio >> version05: spec [
	<version: '0.5' imports: #('0.4-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.5'.
		spec author: 'OffrayLuna'.
		spec timestamp: '2/25/2016 11:43'.
		spec project: 'Ston' with: '0.14'.
		spec package: #Grafoscopio with: 'Grafoscopio-OffrayLuna.152'.
		spec package: #Grafoscopio with: [ spec postLoadDoIt: #postLoadForGrafoscopio ] ].

]

{ #category : #versions }
ConfigurationOfGrafoscopio >> version06: spec [
	<version: '0.6' imports: #('0.5-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.6'.
		spec author: 'OffrayLuna'.
		spec timestamp: '3/2/2016 18:47'.
		spec project: 'Ston' with: '0.14'.
		spec package: #Grafoscopio with: 'Grafoscopio-OffrayLuna.154'.
		spec package: #Grafoscopio with: [ spec postLoadDoIt: #postLoadForGrafoscopio ] ].

]

{ #category : #versions }
ConfigurationOfGrafoscopio >> version07: spec [
	<version: '0.7' imports: #('0.6-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'version 0.7'.
		spec author: 'OffrayLuna'.
		spec timestamp: '2016-04-10T11:32:35.169293-05:00'.
		spec project: 'Ston' with: #'stable'.
		spec package: #Grafoscopio with: 'Grafoscopio-OffrayLuna.174'. 
		spec package: #Grafoscopio with: [ spec postLoadDoIt: #postLoadForGrafoscopio ] ].

]

{ #category : #versions }
ConfigurationOfGrafoscopio >> version08: spec [
	<version: '0.8' imports: #('0.7-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.8'.
		spec author: 'OffrayLuna'.
		spec timestamp: '5/18/2016 17:51'.
		spec 
			project: 'Ston' with: '0.17';
			project: 'Roassal2' with: '1.23'.
		spec package: #Grafoscopio with: 'Grafoscopio-OffrayLuna.183'. ].

]

{ #category : #versions }
ConfigurationOfGrafoscopio >> version09: spec [
	<version: '0.9' imports: #('0.7-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.9'.
		spec author: 'OffrayLuna'.
		spec timestamp: '5/18/2016 17:56'.
		spec 
			project: 'Ston' with: '0.17';
			project: 'Roassal2' with: '1.23'.
		spec package: #Grafoscopio with: 'Grafoscopio-OffrayLuna.184'. ].

]

{ #category : #versions }
ConfigurationOfGrafoscopio >> version11: spec [
	<version: '1.1' imports: #('1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'New GUI with Spec-Glamor bridge integration: read & write notebooks'.
		spec author: 'OffrayLuna'.
		spec timestamp: '9/21/2016 8:01'.
		spec 
			project: 'Ston' with: '0.19';
			project: 'Roassal2' with: '1.35';
			project: 'Dataviz' with: '1.0'.
		spec 
			package: #Grafoscopio with: 'Grafoscopio-OffrayLuna.215';
			package: 'Spec-Glamour' with: 'Spec-Glamour-johanfabry.2'. ].

]

{ #category : #versions }
ConfigurationOfGrafoscopio >> version12: spec [
	<version: '1.2' imports: #('0.8-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'version 1.2'.
		spec author: 'OffrayLuna'.
		spec timestamp: '10/18/2016 18:18'.
		spec 
			project: 'Dataviz' with: '2.1';
			project: 'Roassal2' with: '1.38';
			project: 'Ston' with: #'bleedingEdge'.
		spec 
			package: #Grafoscopio with: 'Grafoscopio-OffrayLuna.235';
			package: 'Spec-Glamour' with: 'Spec-Glamour-johanfabry.2'. ].

]

{ #category : #versions }
ConfigurationOfGrafoscopio >> version1310: spec [
	<version: '1.3.10' imports: #('1.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 1.3.10'.
		spec author: 'OffrayLuna'.
		spec timestamp: '2017-04-28T15:38'.
		spec 
			project: 'Ston' with: #stable;
			project: 'Roassal2' with: #stable;
			project: 'WebBrowser' with: #stable;
			"project: 'Pubiblio' with: #stable;"
			project: 'Dataviz' with: '2.2.4'.
		spec 
			package: #Grafoscopio with: 'Grafoscopio-OffrayLuna.278';
			package: 'Spec-Glamour' with: 'Spec-Glamour-johanfabry.2' ].
]

{ #category : #versions }
ConfigurationOfGrafoscopio >> version1311: spec [
	<version: '1.3.11' imports: #('1.2-baseline' )>

	spec for: #'common' do: [
		spec 
			blessing: #'stable';
			description: 'version 1.3.11';
			author: 'Offray Luna'.
		spec 
			project: 'Ston' with: #stable;
			project: 'Fossil' with: #stable;
			project: 'Roassal2' with: #stable;
			project: 'WebBrowser' with: #stable;
			package: #'Grafoscopio-Utils' with: 'Grafoscopio-Utils-OffrayLuna.13'";
			project: 'Dataviz' with: '2.2.6'".
		spec
			package: #Grafoscopio with: 'Grafoscopio-OffrayLuna.289';
			package: 'Spec-Glamour' with: 'Spec-Glamour-johanfabry.2';
			package: 'Pubiblio' with: 'Pubiblio-OffrayLuna.2'] 
]

{ #category : #versions }
ConfigurationOfGrafoscopio >> version131: spec [
	<version: '1.3.1' imports: #('0.8-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 1.3'.
		spec author: 'Anonymous'.
		spec timestamp: '10/18/2016 19:47'.
		spec 
			project: 'Dataviz' with: '2.2';
			project: 'Roassal2' with: '1.38';
			project: 'Ston' with: '0.3-baseline'.
		spec 
			package: #Grafoscopio with: 'Grafoscopio-OffrayLuna.234';
			package: 'Spec-Glamour' with: 'Spec-Glamour-johanfabry.2'. ].

]

{ #category : #versions }
ConfigurationOfGrafoscopio >> version132: spec [
	<version: '1.3.2' imports: #('1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 1.3.2'.
		spec author: 'OffrayLuna'.
		spec timestamp: '10/18/2016 21:13'.
		spec 
			project: 'Dataviz' with: '2.2.2';
			project: 'Roassal2' with: '1.9';
			project: 'Ston' with: '0.19'.
		spec 
			package: #Grafoscopio with: 'Grafoscopio-OffrayLuna.237';
			package: 'Spec-Glamour' with: 'Spec-Glamour-johanfabry.2'. ].

]

{ #category : #versions }
ConfigurationOfGrafoscopio >> version133: spec [
	<version: '1.3.3' imports: #('1.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 1.3.3'.
		spec author: 'OffrayLuna'.
		spec timestamp: '2016-12-19T18:30'.
		spec 
			project: 'Dataviz' with: '2.2.2';
			project: 'Roassal2' with: #stable;
			project: 'WebBrowser' with: #stable;
			project: 'Ston' with: '0.19'.
		spec 
			package: #Grafoscopio with: 'Grafoscopio-OffrayLuna.245';
			package: 'Spec-Glamour' with: 'Spec-Glamour-johanfabry.2'. ].
]

{ #category : #versions }
ConfigurationOfGrafoscopio >> version134: spec [
	<version: '1.3.4' imports: #('1.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 1.3.4'.
		spec author: 'OffrayLuna'.
		spec timestamp: '2017-02-20T20:40:57'.
		spec 
			project: 'Ston' with: #stable;
			project: 'Dataviz' with: '2.2.2';
			project: 'Roassal2' with: #stable;
			project: 'OSProcess' with: #stable; 
			project: 'WebBrowser' with: #stable.
		spec 
			package: #Grafoscopio with: 'Grafoscopio-OffrayLuna.261';
			package: 'Spec-Glamour' with: 'Spec-Glamour-johanfabry.2'. ].
]

{ #category : #versions }
ConfigurationOfGrafoscopio >> version135: spec [
	<version: '1.3.5' imports: #('1.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 1.3.5'.
		spec author: 'OffrayLuna'.
		spec timestamp: '2/23/2017 18:37'.
		spec 
			project: 'Ston' with: #stable;
			project: 'Roassal2' with: #stable;
			project: 'OSProcess' with: #stable; 
			project: 'WebBrowser' with: #stable;
			project: 'Zotero' with: '0.2';
			project: 'Dataviz' with: '2.2.2'.
		spec 
			package: #Grafoscopio with: 'Grafoscopio-OffrayLuna.261';
			package: 'Spec-Glamour' with: 'Spec-Glamour-johanfabry.2' ].
]

{ #category : #versions }
ConfigurationOfGrafoscopio >> version136: spec [
	<version: '1.3.6' imports: #('1.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 1.3.6'.
		spec author: 'OffrayLuna'.
		spec timestamp: '2017-03-07T16:06'.
		spec 
			project: 'Ston' with: #stable;
			project: 'Roassal2' with: #stable;
			"project: 'OSProcess' with: #stable;" 
			project: 'WebBrowser' with: #stable;
			"project: 'Pubiblio' with: #stable;"
			project: 'Dataviz' with: '2.2.3'.
		spec 
			package: #Grafoscopio with: 'Grafoscopio-OffrayLuna.261';
			package: 'Spec-Glamour' with: 'Spec-Glamour-johanfabry.2' ].
]

{ #category : #versions }
ConfigurationOfGrafoscopio >> version137: spec [
	<version: '1.3.6' imports: #('1.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 1.3.7'.
		spec author: 'OffrayLuna'.
		spec timestamp: '2017-03-07T16:06'.
		spec 
			project: 'Ston' with: #stable;
			project: 'Roassal2' with: #stable;
			"project: 'OSProcess' with: #stable;" 
			project: 'WebBrowser' with: #stable;
			"project: 'Pubiblio' with: #stable;"
			project: 'Dataviz' with: '2.2.3'.
		spec 
			package: #Grafoscopio with: 'Grafoscopio-OffrayLuna.261';
			package: 'Spec-Glamour' with: 'Spec-Glamour-johanfabry.2' ].
]

{ #category : #versions }
ConfigurationOfGrafoscopio >> version138: spec [
	<version: '1.3.8' imports: #('1.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 1.3.8'.
		spec author: 'OffrayLuna'.
		spec timestamp: '2019-02-08T00:00'.
		spec 
			project: 'Ston' with: #stable;
			project: 'Roassal2' with: #stable; 
			project: 'WebBrowser' with: #stable.
		spec 
			package: #Grafoscopio with: 'Grafoscopio-OffrayLuna.374';
			package: 'Spec-Glamour' with: 'Spec-Glamour-johanfabry.2' ].
]

{ #category : #versions }
ConfigurationOfGrafoscopio >> version139: spec [
	<version: '1.3.9' imports: #('1.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 1.3.9'.
		spec author: 'OffrayLuna'.
		spec timestamp: '20 April 2017 T18:06'.
		spec 
			project: 'Ston' with: #stable;
			project: 'Roassal2' with: #stable;
			"project: 'OSProcess' with: #stable;" 
			project: 'WebBrowser' with: #stable;
			"project: 'Pubiblio' with: #stable;"
			project: 'Dataviz' with: '2.2.3'.
		spec 
			package: #Grafoscopio with: 'Grafoscopio-OffrayLuna.271';
			package: 'Spec-Glamour' with: 'Spec-Glamour-johanfabry.2' ].
]

{ #category : #versions }
ConfigurationOfGrafoscopio >> version13: spec [
	<version: '1.3' imports: #('0.8-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 1.3'.
		spec author: 'Anonymous'.
		spec timestamp: '10/18/2016 18:34'.
		spec 
			project: 'Dataviz' with: '2.1';
			project: 'Roassal2' with: '1.38';
			project: 'Ston' with: '0.3-baseline'.
		spec 
			package: #Grafoscopio with: 'Grafoscopio-OffrayLuna.215';
			package: 'Spec-Glamour' with: 'Spec-Glamour-johanfabry.2'. ].

]

{ #category : #versions }
ConfigurationOfGrafoscopio >> version14: spec [
	<version: '1.4' imports: #('1.3-baseline' )>

	spec for: #'common' do: [
		spec 
			blessing: #'stable';
			description: 'version 1.4';
			author: 'Offray Luna'.
		spec 
			project: 'Ston' with: #stable;
			project: 'Fossil' with: #stable;
			project: 'Roassal2' with: #stable;
			project: 'WebBrowser' with: #stable.
		spec
			package: #'Grafoscopio-Utils' with: 'Grafoscopio-Utils-OffrayLuna.26';
			package: #Grafoscopio with: 'Grafoscopio-OffrayLuna.352';
			package: 'Spec-Glamour' with: 'Spec-Glamour-johanfabry.2'.]
]

{ #category : #versions }
ConfigurationOfGrafoscopio >> version151: spec [
	<version: '1.5.1' imports: #('1.3-baseline' )>

	spec for: #'common' do: [
		spec 
			blessing: #'stable';
			description: 'version 1.5.1';
			author: 'Offray Luna'.
		spec 
			project: 'Ston' with: #stable;
			project: 'Fossil' with: #stable;
			project: 'Roassal2' with: #stable;
			project: 'WebBrowser' with: #stable.
		spec
			package: #'Grafoscopio-Utils' with: 'Grafoscopio-Utils-OffrayLuna.32';
			package: #Grafoscopio with: 'Grafoscopio-OffrayLuna.358';
			package: 'Spec-Glamour' with: 'Spec-Glamour-johanfabry.2'.]
]

{ #category : #versions }
ConfigurationOfGrafoscopio >> version152: spec [
	<version: '1.5.2' imports: #('1.3-baseline' )>

	spec for: #'common' do: [
		spec 
			blessing: #'stable';
			description: 'version 1.5.2';
			author: 'Offray Luna'.
		spec 
			"project: 'Ston' with: #stable;"			
			project: 'Fossil' with: #stable;
			project: 'Roassal2' with: #stable;
			project: 'WebBrowser' with: #stable.
		spec
			package: #'Grafoscopio-Utils' with: 'Grafoscopio-Utils-OffrayLuna.32';
			package: #Grafoscopio with: 'Grafoscopio-OffrayLuna.360';
			package: 'Spec-Glamour' with: 'Spec-Glamour-johanfabry.2'.]
]

{ #category : #versions }
ConfigurationOfGrafoscopio >> version153: spec [
	<version: '1.5.3' imports: #('1.3.1-baseline' )>

	spec for: #'common' do: [
		spec 
			blessing: #'stable';
			description: 'version 1.5.3';
			author: 'Offray Luna'.
		spec			
			project: 'Fossil' with: #stable;
			project: 'Roassal2' with: #stable;
			project: 'WebBrowser' with: #stable.
		spec
			package: #'Grafoscopio-Utils' with: 'Grafoscopio-Utils-OffrayLuna.32';
			package: #Grafoscopio with: 'Grafoscopio-OffrayLuna.361';
			package: 'Spec-Glamour' with: 'Spec-Glamour-johanfabry.2'.]
]

{ #category : #versions }
ConfigurationOfGrafoscopio >> version154: spec [
	<version: '1.5.4' imports: #('1.3.2-baseline' )>

	spec for: #'common' do: [
		spec 
			blessing: #'stable';
			description: 'version 1.5.4';
			author: 'Offray Luna'.
		spec			
			project: 'Fossil' with: #stable;
			project: 'Roassal2' with: #stable;
			project: 'WebBrowser' with: #stable.
		spec
			package: #'Grafoscopio-Utils' with: 'Grafoscopio-Utils-OffrayLuna.36';
			package: #Grafoscopio with: 'Grafoscopio-OffrayLuna.361';
			package: 'Spec-Glamour' with: 'Spec-Glamour-johanfabry.2'.]
]

{ #category : #versions }
ConfigurationOfGrafoscopio >> version155: spec [
	<version: '1.5.5' imports: #('1.3.2-baseline' )>

	spec for: #'common' do: [
		spec 
			blessing: #'stable';
			description: 'version 1.5.5';
			author: 'Offray Luna'.
		spec			
			project: 'Fossil' with: #stable;
			project: 'Roassal2' with: #stable;
			project: 'WebBrowser' with: #stable.
		spec
			package: #'Grafoscopio-Utils' with: 'Grafoscopio-Utils-OffrayLuna.36';
			package: #Grafoscopio with: 'Grafoscopio-Offray.365';
			package: 'Spec-Glamour' with: 'Spec-Glamour-johanfabry.2'.]
]

{ #category : #versions }
ConfigurationOfGrafoscopio >> version15: spec [
	<version: '1.5' imports: #('1.3-baseline' )>

	spec for: #'common' do: [
		spec 
			blessing: #'stable';
			description: 'version 1.5';
			author: 'Offray Luna'.
		spec 
			project: 'Ston' with: #stable;
			project: 'Fossil' with: #stable;
			project: 'Roassal2' with: #stable;
			project: 'WebBrowser' with: #stable.
		spec
			package: #'Grafoscopio-Utils' with: 'Grafoscopio-Utils-OffrayLuna.28';
			package: #Grafoscopio with: 'Grafoscopio-OffrayLuna.356';
			package: 'Spec-Glamour' with: 'Spec-Glamour-johanfabry.2'.]
]

{ #category : #versions }
ConfigurationOfGrafoscopio >> version1_0: spec [
	<version: '1.0' imports: #('1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 1.o'.
		spec author: 'OffrayLuna'.
		spec timestamp: '5/26/2016 17:56'.
		spec 
			project: 'Ston' with: '0.17';
			project: 'Roassal2' with: '1.23';
			project: 'Dataviz' with: '1.0'.
		spec 
			package: #Grafoscopio with: 'Grafoscopio-OffrayLuna.188';
			package: 'Spec-Glamour' with: 'Spec-Glamour-johanfabry.2'].

]
